#
# spec file for package rubygem-passenger
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           rubygem-passenger
Version:        4.0.25
Release:        1.16
%define mod_name passenger
%define mod_full_name %{mod_name}-%{version}
%define apxs /usr/sbin/apxs2
%define apache_libexecdir %(%{apxs} -q LIBEXECDIR)
%define apache_sysconfdir %(%{apxs} -q SYSCONFDIR)
%define apache_mmn        %(MMN=$(%{apxs} -q LIBEXECDIR)_MMN; test -x $MMN && $MMN)
%if 0%{?suse_version} > 1100
%define with_system_boost 1
%endif
%define use_system_libev  1
#
#
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  rubygems_with_buildroot_patch
%rubygems_requires
# rake >= 0.8.1
BuildRequires:  rubygem-rake >= 0.8.1
# fastthread >= 1.0.1
BuildRequires:  rubygem-fastthread >= 1.0.1
# daemon_controller >= 0.2.5
BuildRequires:  rubygem-daemon_controller >= 1.0.0
# rack >= 0
BuildRequires:  apache2-devel
BuildRequires:  boost-devel
BuildRequires:  gcc-c++
BuildRequires:  ruby-devel
BuildRequires:  rubygem-rack-1 > 1.0
%if 0%{?suse_version} >= 1110
BuildRequires:  libcurl-devel
%else
BuildRequires:  curl-devel
%endif
BuildRequires:  zlib-devel
%if 0%{?use_system_libev}
BuildRequires:  libev-devel
%endif
Recommends:     packageand(apache2:rubygem-passenger-apache2)
Recommends:     packageand(nginx:rubygem-passenger-nginx)
#
Url:            http://www.modrails.com/
Source:         %{mod_full_name}.gem
# patches are just in for the case i find time to forward port them.
# atm we use the static boost library that ships with passenger
Source1:        rubygem-passenger-2.0.5_system_boost.patch
Source2:        rubygem-passenger-2.0.5_boost_exception.patch
Source3:        rubygem-passenger-2.0.5_missing_includes.patch
Source4:        mod_passenger.conf
Source5:        mod_passenger_root.include
Source6:        nginx_passenger.conf
Source7:        nginx_passenger_root.include
Source11:       rubygem-passenger-3.0.12_boost_threads.patch
Source12:       rubygem-passenger-4.0.14_missing_includes.patch
#
Summary:        Easy and robust Ruby web application deployment
License:        MIT and GPL-2.0
Group:          Development/Languages/Ruby

%description
Easy and robust Ruby web application deployment.

%package nginx
Summary:        Passenger Nginx module for Ruby on Rails support
Group:          Development/Languages/Ruby
Requires:       nginx
Requires:       rubygem-passenger = %{version}

%description nginx
Additional rubygem-passenger module for nginx HTTP-server.

%package apache2
Summary:        Passenger apache module
Group:          Development/Languages/Ruby
Requires:       %{apache_mmn}
Requires:       apache2
Requires:       rubygem-passenger = %{version}

%description apache2
Additional rubygem-passenger module for apache2 HTTP-server.

%package doc
Summary:        RDoc documentation for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       %{name} = %{version}

%description doc
Documentation generated at gem installation time.
Usually in RDoc and RI formats.

%package testsuite
Summary:        Test suite for %{mod_name}
Group:          Development/Languages/Ruby
Requires:       %{name} = %{version}

%description testsuite
Test::Unit or RSpec files, useful for developers.

%package devel-static
Summary:        Files to develop passenger bindings for your webserver
Group:          Development/Languages/Ruby
Requires:       %{name} = %{version}
Provides:       %{name}-devel = %{version}
Requires:	rubygem-rake
Requires:	gcc-c++
%if 0%{?suse_version} >= 1110
Requires:  libcurl-devel
%else
Requires:  curl-devel
%endif
Requires:  zlib-devel
%if 0%{?use_system_libev}
Requires:  libev-devel
%endif

%description devel-static
The 2 static files that are needed to build the nginx extension

%prep

%build

%install
# TODO:
# currently -lev gets lost when using system libev
%if 0%{?use_system_libev}
export USE_VENDORED_LIBEV="no"
%endif
%gem_install %{S:0}
# avoid BUILDROOT leaking into the binaries
mv %{buildroot}%{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}/ .
pushd %{mod_full_name}
  export PATH="%{_sbindir}:$PATH"

  patch --no-backup-if-mismatch -p0 --fuzz=0 -i %{S:11}
  patch --no-backup-if-mismatch -p1 --fuzz=0 -i %{S:12}
  #compiling nginx stuff
  rake nginx:clean nginx CACHING=no

  #compiling apache2 stuff
  rake apache2
  %{__install} -D -m 0755 buildout/apache2/mod_passenger.so %{buildroot}%{apache_libexecdir}/mod_passenger.so
  # cleanup
  %if ! 0%{?use_system_libev}
  make -C ext/libev distclean
  %endif
  find buildout/apache2 -name \*.a -print -delete
  rm -v buildout/apache2/mod_passenger.so
  mv -v buildout/ruby/*/passenger_native_support.so lib/
  rm -rv buildout/ruby/ruby-*-linux
popd
mv %{mod_full_name} %{buildroot}%{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}
%gem_cleanup
find %{buildroot}%{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}/ -name dispatch.\* -print0 | \
    xargs -r0 ruby -p -i -e 'gsub(%r{#!.*/bin/ruby.*}, "#!/usr/bin/ruby")'
%{__install} -D -m 0644 %{S:4} %{buildroot}%{apache_sysconfdir}/conf.d/mod_passenger.conf
%{__install} -D -m 0644 %{S:5} %{buildroot}%{apache_sysconfdir}/conf.d/mod_passenger_root.include
%{__sed} -i -e "s,@PassengerRoot@,%{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}," %{buildroot}%{apache_sysconfdir}/conf.d/mod_passenger_root.include
%{__install} -D -m 0644 %{S:6} %{buildroot}/etc/nginx/conf.d/passenger.conf
%{__install} -D -m 0644 %{S:7} %{buildroot}/etc/nginx/conf.d/passenger_root.include
%{__sed} -i -e "s,@PassengerRoot@,%{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}," %{buildroot}/etc/nginx/conf.d/passenger_root.include
%{__rm} -v %{buildroot}%{_bindir}/passenger-install-*-module
find %{buildroot}%{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}/{ext,test} -type f -print0 | xargs -r0 chmod a-x
chmod a+r %{buildroot}%{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}/helper-scripts/download_binaries/*

%files nginx
%defattr(-,root,root)
#%{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}/agents/nginx
%dir /etc/nginx
%dir /etc/nginx/conf.d
%config(noreplace) /etc/nginx/conf.d/passenger.conf
%config            /etc/nginx/conf.d/passenger_root.include

%files apache2
%defattr(-,root,root)
%{apache_libexecdir}/mod_passenger.so
%config(noreplace) %{apache_sysconfdir}/conf.d/mod_passenger.conf
%config            %{apache_sysconfdir}/conf.d/mod_passenger_root.include
#%{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}/agents/apache2

%files
%defattr(-,root,root,-)
%{_bindir}/passenger
%{_bindir}/passenger-config
%{_bindir}/passenger-status
%{_bindir}/passenger-memory-stats
#%{_bindir}/passenger-make-enterprisey
%{_libdir}/ruby/gems/%{rb_ver}/cache/%{mod_full_name}.gem
%{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}/
# doc and testsuite subpackage
%exclude %{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}/test
%{_libdir}/ruby/gems/%{rb_ver}/specifications/%{mod_full_name}.gemspec
# backend subpackages
#%exclude %{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}/agents/apache2
#%exclude %{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}/agents/nginx
# needed to build the nginx extension
%exclude %{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}/buildout/common/libboost_oxt.a
#%exclude %{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}/buildout/common/libpassenger_common.a

%files doc
%defattr(-,root,root,-)
%doc %{_libdir}/ruby/gems/%{rb_ver}/doc/%{mod_full_name}/

%files testsuite
%defattr(-,root,root,-)
%{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}/test

%files devel-static
%defattr(-,root,root,-)
%{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}/buildout/common/libboost_oxt.a
#%{_libdir}/ruby/gems/%{rb_ver}/gems/%{mod_full_name}/buildout/common/libpassenger_common.a

%changelog
* Thu Nov 21 2013 cs@linux-administrator.com
- update to version 4.0.25
* Wed Nov  6 2013 coolo@suse.com
- updated to version 4.0.23
  * Fixed compilation problems on GCC 4.8.2 (e.g. Arch Linux 2013-10-27).
  * Fixed a compatibility problem with Solaris /usr/ccs/bin/make: issue #999.
  * Support for the Meteor Javascript framework has been open sourced.
* Thu Oct 31 2013 coolo@suse.com
- updated to version 4.0.21
  * Supports JRuby 1.7.6.
  * Open sourced Node.js support.
  * [Nginx] Upgraded the preferred Nginx version to 1.4.3.
  * Work around an Apache packaging bug in CentOS 5.
  * Various user friendliness improvements in the documentation and the installers.
  * Fixed a bug in the always_restart.txt support. Phusion Passenger was looking for it in the wrong directory.
  * [Standalone] The –temp-dir command line option has been introduced.
* Thu Oct 10 2013 coolo@suse.com
- updated to version 4.0.20
  * Fixed a bug in Phusion Passenger Standalone's daemon mode. When in daemon
    mode, the Nginx temporary directory was deleted prematurely, causing some
    POST requests to fail. This was a regression that was introduced in 4.0.15
    as part of an optimization.
  * Fixed compilation problems on Solaris 10 with Sun Studio 12.3.
  * Improved detection of RVM problems.
  * It is now possible to log the request method to Union Station.
  * Introduced a new option, `PassengerLoadShellEnvvars` (Apache) and
    `passenger_load_shell_envvars` (Nginx). This allows enabling or disabling
    the loading of bashrc before spawning the application.
  * [Enterprise] Fixed a packaging problem which caused the flying-passenger
    executable not to be properly included in the bin path.
  * [Enterprise] Fixed a race condition which sometimes causes the Flying
    Passenger socket to be deleted after a restart. Fixes issue #939.
  * [Enterprise] The `byebug` gem is now supported for debugging on Ruby 2.0.
    The byebug gem requires a patch before this works:
    https://github.com/deivid-rodriguez/byebug/pull/29
* Fri Oct  4 2013 coolo@suse.com
- updated to version 4.0.19
  * Fixed a problem with response buffering. Application processes are now
    properly marked available for request processing immediately after they're
    done sending the response, instead of after having sent the entire response
    to the client.
  * The "processed" counter in `passenger-status` is now bumped after the process
    has handled a request, not at the beginning.
  * [Enterprise] Fixed an off-by-one bug in the `passenger_max_processes` setting.
* Tue Oct  1 2013 coolo@suse.com
- fix permissions to fix nginx build
* Wed Sep 25 2013 coolo@suse.com
- update to version 4.0.18
  * The Enterprise variant of Phusion Passenger Standalone now supports
    customizing the concurrency model and thread count from the command line.
  * On Nginx, the Enterprise license is now only checked if Phusion Passenger
    is enabled in Nginx. This allows you to deploy Nginx binaries, that have
    Phusion Passenger Enterprise compiled in, to servers that are not
    actually running Phusion Passenger Enterprise.
  * Fixed a performance bug in the Union Station support code. In certain cases
    where a lot of data must be sent to Union Station, the code is now over
    100 times faster.
  * `passenger-status --show=union_station` now displays all clients that
    are connected to the LoggingAgent.
  * Added a workaround for Heroku so that exited processes are properly detected
    as such.
  * When using Phusion Passenger Standalone with Foreman, pressing Ctrl-C
    in Foreman no longer results in runaway Nginx processes.
  * Fixed backtraces in the Apache module.
* Tue Sep 17 2013 adrian@suse.de
- restore build of apache2 and ngnix modules
* Fri Sep 13 2013 coolo@suse.com
- updated to version 4.0.17
  * Fixed compilation problems on GCC 4.8 systems, such as Arch Linux 2013.04.
  Fixes issue #941.
  * Fixed some deprecation warnings when compiling the Ruby native extension
  on Ruby 2.0.0.
  * Fixed some Union Station-related stability issues.
* Sat Sep  7 2013 coolo@suse.com
- updated to version 4.0.16, see
  http://blog.phusion.nl/category/passenger/phusion-passenger-4/
* Tue Aug 27 2013 coolo@suse.com
- add rubygem-passenger-4.0.14_missing_includes.patch to fix
  build
* Mon Aug 26 2013 coolo@suse.com
- updated to version 4.0.14, see
  http://blog.phusion.nl/category/passenger/phusion-passenger-4/
* Sat Jul 20 2013 coolo@suse.com
- updated to version 4.0.10, see
  http://blog.phusion.nl/category/passenger/phusion-passenger-4/
- obsoletes rubygem-passenger-aarch64-support.patch and
  config-guess-sub-update.diff
* Sun Jun 16 2013 dmueller@suse.com
- add config-guess-sub-update.diff
- add rubygem-passenger-aarch64-support.patch
- add zlib-devel buildrequires
* Fri May 31 2013 coolo@suse.com
- update to version 4.0.5
  Fixed security vulnerability CVE-2013-2119 and many other things
* Mon May 27 2013 coolo@suse.com
- avoid leaking %%buildroot into binaries
* Mon May 27 2013 coolo@suse.com
- update to version 4.0.3, see
  http://blog.phusion.nl/category/passenger/phusion-passenger-4/
* Fri May 17 2013 coolo@suse.com
- update to version 4.0.2 - new branch, see
  http://blog.phusion.nl/category/passenger/phusion-passenger-4/
* Thu Jan 10 2013 coolo@suse.com
- update to version 3.0.19
  * Nginx security fix: do not display Nginx version when
  server_tokens are off.
  * Fixed compilation problems on some systems.
  * Fixed some Union Station-related bugs.
* Wed Oct 31 2012 coolo@suse.com
- updated to version 3.0.18
  * Fixed compilation problems on Fedora 17.
  * Fixed Union Station compatibility with Rails 3.2.
  * Phusion Passenger Enterprise Standalone now supports rolling
    restarts and deployment error resistance.
* Thu Aug 30 2012 coolo@suse.com
- update to 3.0.17
  * Fixed a Ruby 1.9 encoding-related bug in the memory measurer.
    (Phusion Passenger Enterprise)
  * Fixed OOM adjustment bugs on Linux.
  * Fixed compilation problems on Fedora 18 and 19.
  * Fixed compilation problems on SunOS.
  * Fixed compilation problems on AIX. Contribution by Perry Smith.
  * Fixed various compilation warnings.
  * Upgraded preferred Nginx version to 1.2.3.
  * Updated documentation.
  * Updated website links.
* Tue Aug 28 2012 coolo@suse.com
- apply boost changes for new glibc to copy
* Fri Aug  3 2012 coolo@suse.com
- updated to version 3.0.15
  * updated docu
* Sun Jul 22 2012 coolo@suse.com
- update to 3.0.14
  * [Apache] Fixed a long-standing mod_rewrite-related problem.
    Some mod_rewrite rules would not work, but it depends on the exact
    mod_rewrite configuration so it would work for some people but not
    for others. Issue #563. Thanks a lot to cedricmaion for providing
    information on the nature of the bug and to peter.nash55 for
    providing a VM that allowed us to reproduce the problem.
  * [Nginx] Preferred Nginx version to 1.2.2.
    The previously preferred version was 1.2.1.
  * Cleared some confusing terminology in the documentation.
  * Fixed some Ruby 1.9 encoding problems.
* Sun Jul 15 2012 coolo@suse.com
- update to 3.0.13
  * [Nginx] Preferred Nginx version upgraded to 1.2.1.
  * Fixed compilation problems on FreeBSD 6.4. Fixes issue #766.
  * Fixed compilation problems on GCC >= 4.6.
  * Fixed compilation problems on OpenIndiana and Solaris 11. Fixes issue #742.
  * Union Station-related bug fixes.
  * Sending the soft termination signal twice to application processes no longer makes them crash. Patch contributed by Ian Ehlert.
* Fri Jun 29 2012 coolo@suse.com
- do not require package names but generic provides for easier update
  of those
* Sat May 12 2012 coolo@suse.com
- fix compilation with gcc 4.7
* Sat May 12 2012 coolo@suse.com
- update to 3.0.12
  * [Apache] Support Apache 2.4. The event MPM is now also supported.
  * [Nginx] Preferred Nginx version upgraded to 1.0.15.
  * [Nginx] Preferred PCRE version upgraded to 8.30.
  * [Nginx] Fixed compatibility with Nginx < 1.0.10.
  * [Nginx] Nginx is now installed with http_gzip_static_module by default.
  * [Nginx] Fixed a memory disclosure security problem.
    The issue is documented at http://www.nginx.org/en/security_advisories.html
    and affects more modules than just Phusion Passenger. Users are advised
    to upgrade as soon as possible. Patch submitted by Gregory Potamianos.
  * [Nginx] passenger_show_version_in_header now hides the Phusion Passenger version number from the 'Server:' header too.
    Patch submitted by Gregory Potamianos.
  * Fixed a /proc deprecation warning on Linux kernel >= 3.0.
  * Fixed a compilation problem on platforms without alloca.h, such as FreeBSD 7.
  * Improved performance and solved some warnings on Xen systems by compiling
    with `-mno-tls-direct-seg-refs`. Patch contributed by Michał Pokrywka.
  * [Nginx] Dropped support for Nginx versions older than 1.0.0
  * [Nginx] Fixed support for Nginx 1.1.4+
  * [Nginx, Standalone] Upgraded default Nginx version to 1.0.10
    The previously default version was 1.0.5.
  * [Nginx] New option passenger_max_requests
    This is equivalent to the PassengerMaxRequests option in the Apache
    version: Phusion Passenger will automatically shutdown a worker process
    once it has processed the specified number of requests.
    Contributed by Paul Kmiec.
  * [Apache] New option PassengerBufferResponse
    The Apache version did not buffer responses. This could block the Ruby
    worker process in case of slow clients. We now enable response buffering
    by default. It can be turned off through this option. Feature contributed
    by Ryo Onodera.
  * Fixed remaining Ruby 1.9.3 compatibility problems
    We already supported Ruby 1.9.3 since 3.0.8, but due to bugs in Ruby
    1.9.3's build system Phusion Passenger would fail to detect Ruby 1.9.3
    features on some systems. Fixes issue #714.
  * Fixed a bug in PassengerPreStart
    A regression was introduced in 3.0.8, causing the prespawn script to
    connect to the host name instead of to 127.0.0.1. Fix contributed by
    Andy Allan.
  * Fixed compatibility with GCC 4.6
    Affected systems include Ubuntu 11.10.
  * Fixed various compilation problems.
  * Fixed some Ruby 1.9 encoding problems.
  * Fixed some Ruby 1.9.3 deprecation warnings.
* Tue Feb 21 2012 jreidinger@suse.com
- add ruby-devel build requirements. Ensuring proper build for
  older distribution.
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Sat Dec  3 2011 dmueller@suse.de
- fix build on arm
* Mon Oct 24 2011 schubi@suse.com
- Reducing requirement of rubygem-rack to 1_1 cause 1_3 produces
  problems with rails.
* Wed Oct 19 2011 fcastelli@suse.com
- Update to 3.0.9:
  * [Nginx] Fixed a NULL pointer crash that occurs on HTTP/1.0 requests
    when the Host header isn't given.
  * Fixed deprecation warnings on RubyGems >= 1.6.
  * Improved Union Station support stability.
* Tue Oct 18 2011 schubi@suse.com
- added rubygem-rack-1_3 in order to avoid choice error while
  building
* Wed Oct 12 2011 roman@priesol.net
- [Nginx] Fixed line without semicolon
* Fri Sep 23 2011 roman@priesol.net
- [Nginx] Fixed include path
* Mon Aug 22 2011 mrueckert@suse.de
- update to version 3.0.8
  * [Nginx] Upgraded preferred Nginx version to 1.0.5.
  * [Nginx] Fixed various compilation problems on various platforms.
  * [Nginx] We now ensure that SERVER_NAME is equal to HTTP_HOST
    without the port part.  This is needed for Rack compliance. By
    default Nginx sets SERVER_NAME to whatever is specified in the
    server_name directive, but that's not necessarily the correct
    value. This fixes, for example, the use of the 'map' statement
    in config.ru.
  * [Nginx] Added the options passenger_buffer_size,
    passenger_buffers and passenger_busy_buffers_size.  These
    options are similar to proxy_module's similarly named options.
    You can use these to e.g. increase the maximum header size
    limit.
  * [Nginx] passenger_pre_start now supports virtual hosts that
    listen on Unix domain sockets.
  * [Apache] Fixed the pcre.h compilation problem.
  * [Standalone] Fixed 'passenger stop'.
    It didn't work properly because it kept waiting for 'tail' to
    exit.  We now properly terminate 'tail' as well.
  * Fixed compatibility with Rake 0.9.
  * Fixed various Ruby 1.9 compatibility issues.
  * Various documentation improvements.
  * New Union Station filter language features.
    It now supports status codes and response times.  Please refer
    to https://engage.unionstationapp.com/help#filtering for more
    information.
* Mon Aug 22 2011 mrueckert@suse.de
- make sure the passenger root variable always points to the
  passenger version in the package. To achieve that we introduce a
  (mod_)passenger_root.include file which will be included from the
  old (mod_)passenger.conf. the new file is not marked as
  config(noreplace) and will be overwritten by the package.
* Tue Aug 16 2011 mrueckert@suse.de
- buildrequire rubygem-rack-1_3 to fix the have choice problem
- use the mod_full_name macro
* Wed Jun  8 2011 ammler@openttdcoop.org
- add config template to -nginx subpackage
* Mon May  2 2011 mrueckert@suse.de
- require nginx in the -nginx subpackage
* Sun Apr 24 2011 mrueckert@suse.de
- fix build on devel_languages_ruby_SLE_10
  use curl-devel for anything older than sle11/11.1
* Thu Apr 14 2011 mrueckert@suse.de
- switch to use system libev
* Thu Apr 14 2011 mrueckert@suse.de
- update to version 3.0.7
  * Upgraded preferred Nginx version to 1.0.0.
  * Phusion Passenger Standalone now pre-starts application processes
  at startup instead of doing that at the first request.
  * When sending data to Union Station, the HTTP status code is now
  also logged.
  * Various Union Station-related stability improvements.
  * The Linux OOM killer was previously erroneously disabled for all
  Phusion Passenger processes, including application processes. The
  intention was to only disable it for the Watchdog. This has been
  fixed, and the Watchdog is now the only process for which the OOM
  killer is disabled.
  * Due to a typo, the dependency on file-tail was not entirely
  removed in 3.0.6. This has now been fixed.
- fixed cleaning up the ext tree
* Tue Apr 12 2011 mrueckert@suse.de
- split out a devel-static package containing the 2 static
  libraries that you need to compile nginx with passenger support
  later.
  that saves us recompiling them in the nginx build.
- clean up file lists
* Tue Apr 12 2011 mrueckert@suse.de
- update to version 3.0.6
  * Fixed various Union Station-related stability issues.
  * Fixed an issue with host name detection on certain platforms.
  * Improved error logging in various parts.
  * The dependency on the file-tail library has been removed.
  * During installation, check whether /tmp is mounted with 'noexec'.
  Phusion Passenger's installer relies on /tmp *not* being mounted
  with 'noexec'. If it is then the installer will now show a
  helpful error message instead of bailing out in a confusing
  manner. Users can now tell the installer to use a different
  directory for storing temporary files by customizing the $TMPDIR
  environment variable.
  * Phusion Passenger Standalone can now run Rackup files that are
  not named 'config.ru'.  The filename can be passed through the
  command line using the -R option.
- additional changes from 3.0.5
  * [Apache] Fixed Union Station process statistics collection
  Union Station users that are using Apache may notice that no
  process information show up in Union Station. This is because of
  a bug in Phusion Passenger's Apache version, which has now been
  fixed.
  * [Apache] PassengerAnalytics has been renamed to
  UnionStationSupport This option has been renamed for consistency
  reasons.
  * [Nginx] passenger_analytics has been renamed to
  union_station_support This option has been renamed for
  consistency reasons.
  * Fixed Union Station data sending on older libcurl versions
  Some Union Station users have reported that their data don't
  show up.  Upon investigation this turned out to be a
  compatibility with older libcurl versions. Affected systems
  include all RHEL 5 based systems, such as RHEL 5.5 and CentOS
  5.5. We've now fixed compatibility with older libcurl versions.
  * Added support for the Union Station filter language
  This language can be used to limit the kind of data that's sent
  to Union Station. Please read
  https://engage.unionstationapp.com/help#filtering for details.
  * Fixed a PassengerMaxPoolSize/passenger_max_pool_size violation
  bug People who host a lot of different applications on Phusion
  Passenger may notice that it sometimes spawns more processes
  than is allowed by PassengerMaxPoolSize/passenger_max_pool_size.
  This has been fixed.
- additional changes from 3.0.4
  * [Apache] Changed mod_dir workaround hook priority
  Phusion Passenger temporarily disables mod_dir on all Phusion
  Passenger-handled requests in order to avoid conflicts. In order
  to do this it registers some Apache hooks with the
  APR_HOOK_MIDDLE priority, but it turned out that this breaks
  some other modules like mod_python. The hook priority has been
  changed to APR_HOOK_LAST to match mod_dir's hook priorities.
  Issue reported by Jay Freeman.
  * Added support for Union Station: http://www.unionstationapp.com/
  * Some error messages have been improved.
* Fri Feb 25 2011 mrueckert@suse.de
- update to version 3.0.3
  * [Nginx] Preferred Nginx version upgraded to 0.8.54
    The previous preferred version was 0.8.53.
  * PATH_INFO and REQUEST_URI now contain the original escaped URI
    Phusion Passenger passes the URI, as reported by Apache/Nginx,
    to application processes through the PATH_INFO and REQUEST_URI
    variables.  These variables are supposed to contain the
    original, unescaped URI, e.g.  /clubs/%%C3%%BC. Both Apache and
    Nginx thought that it would be a good idea to unescape the URI
    before passing it to modules like Phusion Passenger, thereby
    causing PATH_INFO and REQUEST_URI to contain the unescaped URI,
    e.g. /clubs/ü. This causes all sorts of encoding problems. We
    now manually re-escape the URI when setting PATH_INFO and
    REQUEST_URI. Issue #404.
  * The installer no longer detects directories as potential
    commands Previously the installer would look in $PATH for
    everything that's executable, including directories. If one has
    /usr/lib in $PATH and a directory /usr/lib/gcc exists then the
    installer would recognize /usr/lib/gcc as the compiler. We now
    explicitly check whether the item is also a file.
  * PseudoIO now responds to #to_io
    Phusion Passenger sets STDERR to a PseudoIO object in order to
    capture anything written to STDERR during application startup.
    This breaks some libraries which expect STDERR to respond to
    [#]to_io. This has now been fixed. Issue #607.
  * Fixed various other minor bugs
    See the git commit log for details.
- splitted out testsuite and documentation
* Thu Jan 20 2011 mrueckert@suse.de
- moved apache2 requires to the apache2 subpackage
* Thu Jan 13 2011 chris@computersalat.de
- fix spec
  o Group field must be present in package: rubygem-passenger-nginx
* Thu Jan 13 2011 schubi@novell.com
- Spit packages into
  - - rubygem-passenger
  - - rubygem-passenger-nginx
  - - rubygem-passenger-apache2
* Tue Dec 21 2010 chris@computersalat.de
- update to version 3.0.2
  * [Nginx] Fix crash if passenger_root refers to a nonexistant
    directory.
  * Fixed file descriptor closing issues on FreeBSD: issue #597.
  * Fix the fakeroot task. Issue #592
  * Update NEWS.
  * Fix Nginx configure script: it didn't correctly change back the
    orginal working directory after compilation.
  * NetBSD doesn't support llroundl() so work around it by using
    llround(). Issue #593.
  * Fix compilation warning on NetBSD: issue #593.
  * Fix use of fcntl(.., F_CLOSEM)
  * Merge branch 'master' into debian
  * Add support to EventedClient for only closing the writer half
    of the connection.
  * Add StaticString.find(substring)
  ... and lot more
* Tue Dec  7 2010 mrueckert@suse.de
- update to version 3.0.1
  * Fixed malfunction after web server restart
  On Linux systems that have a non-standard filesystem on /tmp, Phusion
  Passenger could malfunction after restarting the web server because of
  a bug that's only triggered on certain filesystems. Issue #569.
  * Boost upgraded to version 1.44.0.
  We were on 1.42.0.
  * Much improved startup error messages
  Phusion Passenger performs many extensive checks during startup to ensure
  integrity. However the error message in some situation could be vague.
  These startup error messages have now been improved dramatically, so that
  if something goes wrong during startup you will now more likely know why.
  * Curl < 7.12.1 is now supported
  The previous version fails to compile with Curl versions earlier than
  7.12.1. Issue #556.
  * passenger-make-enterprisey fixed
  This is the command that people can run after donating. It allows people
  to slightly modify Phusion Passenger's display name as a joke. In 3.0.0 it
  was broken because of a typo. This has been fixed.
  * Removed passenger-stress-test
  This tool was used during the early life of Phusion Passenger for stress
  testing websites. Its performance has never been very good and there are
  much better tools for stress testing, so this tool has now been removed.
  * [Apache] RailsEnv and RackEnv configuration options are now equivalent
  In previous versions, RailsEnv only had effect on Rails 1 and Rails 2 apps
  while RackEnv only had effect on Rack apps. Because Rails 3 apps are
  considered Rack apps, setting RailsEnv had no effect on Rails 3 apps.
  Because this is confusing to users, we've now made RailsEnv and RackEnv
  equivalent. Issue #579.
  * [Nginx] Fixed compilation problems on systems with unpowerful shells
  Most notably Solaris. Its default shell does not support some basic
  constructs that we used in the Nginx configure script.
  * [Nginx] Upgraded default Nginx version to to 0.8.53
  The previous default was 0.8.52.
  * [Nginx] passenger_enabled now only accepts 'on' or 'off' values
  Previously it would recognize any value not equal to 'on' as meaning
  'off'. This caused confusion among users who thought they could also
  specify 'true', so we now throw a proper error if the value is
  unrecognized. Fixes issue #583.
- cleaned up spec file
- move passenger_native_support from ext to lib dir (bnc#657964)
* Thu Oct 28 2010 mrueckert@suse.de
- update to version 3.0.0
  This is a major release with many changes. Please read our blog
  for details.
  http://blog.phusion.nl/2010/10/18/phusion-passenger-3-0-0-final-released/
- new dependencies:
  rubygem-daemon_controller
  rubygem-file-tail
  libcurl
* Fri Jul  9 2010 mrueckert@suse.de
- mark mod_passenger.conf config(noreplace)
* Fri Jun 25 2010 mrueckert@suse.de
- update to version 2.2.15
  - [Apache] Fixed incorrect temp dir cleanup by passenger-status
    On some systems, running passenger-status could print the
    following message: "*** Cleaning stale folder
    /tmp/passenger.1234" ...after which Phusion Passenger breaks
    because that directory is necessary for it to function
    properly. The cause of this problem has been found and has been
    fixed.
  - [Apache] Fixed some upload handling problems Previous versions
    of Phusion Passenger check whether the size of the received
    upload data matches the contents of the Content-Length header
    as received by the client. It turns out that there could be a
    mismatch e.g. because of mod_deflate input compression, so we
    can't trust Content-Length anyway and we're being too strict.
    The check has now been removed.
  - [Nginx] Fixed compilation issues with Nginx >= 0.7.66 Thanks to
    Potamianos Gregory for reporting this issue. Issue #500.
  - [Nginx] Default Nginx version changed to 0.7.67 The previous
    default version was 0.7.65.
  - Fixed more Bundler problems Previous versions of Phusion
    Passenger would preload some popular libraries such as mysql
    and sqlite3 in order to utilize copy-on-write optimizations
    better.  However this behavior conflicts with Bundler so we've
    removed it.
* Mon Jun 14 2010 mrueckert@suse.de
- update to version 2.2.14
  * Added support for Rubinius
    Patch contributed by Evan Phoenix.
  * Fixed a mistake in the SIGQUIT backtrace message.
    Patch contributed by Christoffer Sawicki.
  * [Nginx] Fix a localtime() crash on FreeBSD
    This was caused by insufficient stack space for threads.
    Issue #499.
- additional changes from version 2.2.13
  * Fixed some Rails 3 compatibility issues that were recently
    introduced.
  * Fixed a typo that causes config/setup_load_paths.rb not to be
    loaded correctly.
- additional changes from version 2.2.12
  * Improved Bundler support.
    Previous versions might not be able to correctly load gems
    bundled by Bundler. We've also documented how our Bundler
    support works and how to override our support if you need
    special behavior.  Please refer to the Phusion Passenger Users
    Guide, section "Bundler support".
  * Worked around some user account handling bugs in Ruby.
    Issue #192.
  * Fixed some Ruby 1.9 tempfile.rb compatibility problems.
  * Fixed some compilation problems on some ARM Linux platforms.
  * [Apache] Suppress bogus mod_xsendfile-related error messages.
    When mod_xsendfile is being used, Phusion Passenger might print
    bogus error messages like "EPIPE" or "Apache stopped forwarding
    the backend's response" to the log file. These messages are
    normal, are harmless and can be safely ignored, but they
    pollute the log file. So in this release we've added code to
    suppress these messages when mod_xsendfile is being used.
    Issue #474.
  * [Nginx] Fixed "passenger_user_switching off" permission
    problems If Nginx is running as root and
    passenger_user_switching is turned off, then Phusion Passenger
    would fail to initialize because of a permission problem. This
    has been fixed. Issue #458.
  * [Nginx] Nginx >= 0.8.38 is now supported.
    Thanks to Sergey A. Osokin for reporting the problem.
  * [Nginx] passenger-install-nginx-module upgraded
    It now defaults to installing Nginx 0.7.65 instead of 0.7.64.
* Fri Jun 11 2010 mrueckert@suse.de
- use rubygems_requires macro
* Tue Mar 16 2010 chris@computersalat.de
- update to version 2.2.11
  * This release fixes a regression that appeared in 2.2.10 which only
  affects Apache. When under high load, Apache might freeze and stop
  responding to requests. It is caused by a race conditions which is
  why it escaped our last release testing.
- fix initializer problem
  o do not install ApplicationPoolServerExecutable to
    /usr/lib/phusion_passenger
    leave at origin place and set correct @PassengerRoot@ in
    mod_passenger.conf
* Thu Feb 25 2010 mrueckert@suse.de
- update to version 2.2.10
  * Fixed some Bundler compatibility problems.
  * Fixed some file descriptor passing problems, which previously
  could lead to mysterious crashes.
  * Fixed some compilation problems on newer GCC versions. Issue #430.
  * Support #size method in rack.input.
- for changes from 2.2.8 and 2.2.9 see
  /usr/lib*/ruby/gems/1.8/gems/passenger-2.2.10/NEWS
* Wed Dec  2 2009 chris@computersalat.de
- update to version 2.2.7
  * Removed forgotten debugging code in passenger-install-apache2-module,
  which caused it not to compile anything.
- additional changes from 2.2.6
  * Some /tmp cleaner programs such as tmpwatch try to remove
  subdirectories in /tmp/passenger.xxx after a while because they
  think those subdirectories are unused. This could cause Phusion
  Passenger to malfunction, requiring a web server restart.
  Measures have now been taken to prevent those tmp cleaner
  programs from removing anything in /tmp/passenger.xxx. Issue #365.
  * When autodetecting the application type, Rack is now given more
  priority than Rails. This allows one to drop a config.ru file in
  a Rails directory and have it detected as a Rack application
  instead of a Rails application.  Patch contributed by Sam
  Pohlenz: issue #338.
  * The default socket backlog has been increased from 'SOMAXCONN'
  (which is 128 on most platforms) to 1024. This should fix most
  'helper_server.sock failed: Resource temporarily unavailable'
  errors.
  * Fixed compilation problems on Solaris. Issue #369 and issue #379.
  * Fixed crashes on PowerPC.
  * Some Ruby 1.9 compatibility fixes. Issue #398.
  * The installer now displays correct dependency installation
  instructions for Mandriva Linux.
  * [Apache] The location of the 'apxs' and 'apr-config' commands
  can now also be passed to the installer through the --apxs-path
  and --apr-config-path parameters, in addition to the $APXS2 and
  $APR_CONFIG environment variables. Issue #3.
  * [Nginx] Various problems that only occur on 64-bit platforms
  have been fixed.
  * [Nginx] The installer now installs Nginx 0.7.64 by default.
- fix Passenger could not be initialized
  o '/usr/lib/phusion_passenger/ApplicationPoolServerExecutable'
* Fri Oct 16 2009 mrueckert@suse.de
- update to version 2.2.5
  see /usr/lib*/ruby/gems/1.8/gems/passenger-2.2.5/NEWS
* Thu Mar 26 2009 mrueckert@suse.de
- update to version 2.1.2
  - Support for Rails 2.3
  - Improved compatibility with other Apache modules, such as
    mod_rewrite
  - Ruby 1.9 support
  - Support for NFS setups
  - Various I/O handling and scaling improvements and fixes
  - Ability to disable Phusion Passenger for arbitrary URLs
    (PassengerEnabled option)
  - Improved application compatibility
  - Improved command-line admin tools
  - Ability to display backtraces for all threads
  - Improved security
  - More customization options for exotic systems/setups
  - Various usability improvements
  - In particular, many error messages have been improved so that
    end users don’t have to stare at the screen for minutes
    wondering what the computer is trying to tell them. There are
    also many small usability improvements here and there.
  - Various other minor improvements and bug fixes
  - PassengerPoolIdleTime can now be set to 0, which means that
    the backend application must never idle timeout. This feature
    has been contributed by redmar.
  - The passenger-status tool will now display Phusion
    Passenger’s own backtraces for C++ code, in order to make it
    possible to detect potential freezes in C++ code.
  - Phusion Passenger error pages now return HTTP 500 errors, as
    they should.
  - The ApplicationSpawner server and FrameworkSpawner server
    idle times can now be customized.
  - In the 2.0.x series, sometimes more backend processes might
    be spawned than is allowed by the ‘PassengerMaxPoolSize’
    option. This has been fixed.
* Tue Jan 13 2009 mrueckert@suse.de
- fix path for apache config
* Fri Dec 19 2008 mrueckert@suse.de
- add basic apache config
- fix path to native_support
* Fri Dec 19 2008 mrueckert@suse.de
- fix requires
* Wed Dec 17 2008 mrueckert@suse.de
- update to version 2.0.6
  Fixed Ruby 1.8.5 compatibility
    In the previous release, we fixed Ruby 1.8.7 compatibility,
    but this broke 1.8.5. We’ve fixed this.
  Removed unintentional dependency on MySQL and SQLite
    Phusion Passenger 2.0.5 preloads the mysql and sqlite3
    libraries when running in Ruby Enterprise Edition, for better
    copy-on-write efficiency. But it didn’t take into account that
    these libraries may not be installed. This has been fixed.
* Fri Dec  5 2008 mrueckert@suse.de
- use boost copy from gem when building on older distros.
  split rubygem-passenger-2.0.5_system_boost.patch into:
  rubygem-passenger-2.0.5_boost_exception.patch
  rubygem-passenger-2.0.5_system_boost.patch
- added rubygem-passenger-2.0.5_missing_includes.patch
* Fri Dec  5 2008 mrueckert@suse.de
- initial package of version 2.0.5
